[Splash Screen]
Engine=simple

[General]
SessionName=Default
SaveOnExit=true

# This the default session launched by xfce4-session if the
# user hasn't saved any session yet or creates a new session.
[Failsafe Session]
Count=4
Client0_Command=xfwm4
Client0_PerScreen=False
Client1_Command=xfce4-panel
Client1_PerScreen=False
Client2_Command=Thunar,--daemon
Client2_PerScreen=False
Client3_Command=xfdesktop
Client3_PerScreen=False

